# Recent acceleration of a Greenlandic lake-terminating ice margin

## Code
- The [`environment.yml`](/environment.yml) file needed to re-create the python environment
- [`plot_figures.ipynb`](/code/plot_figures.ipynb) contains all the code necessary to reproduce the figures
## Data
- [`tps.geojson`](/data/tps.geojson) are the manually digitized terminus traces.
- [`tpBox.geojson`](/data/tpBox.geojson) are the reference boxes used to calculate terminus retreat.
- [`sampleCentrelines.geojson`](/data/sampleCentrelines.geojson) are the glacier centrelines used in this study
- [`samplePoints_feather`](/data/samplePoints_feather) (which can be read with `geopandas.read_feather()`) contains the points along these centrelines which are used to sample the ice velocity, and surface elevation datasets

Note: all coordinates are in EPSG:3413 - WGS 84 / NSIDC Sea Ice Polar Stereographic
***
### Ice velocity
Velocity data generated using auto-RIFT (Gardner et al., 2018) and provided by the [NASA MEaSUREs ITS_LIVE project](https://its-live.jpl.nasa.gov/) (Gardner et al., 2023).
- No download required
- Accessed via cloud-optimized `Zarr` data-cubes stored in AWS S3.
- Note: this is a *live* dataset, and is liable to change. Figures in publication were checked and re:run in April 2023.
***
### Surface elevation change
#### CryoTEMPO-EOLIS
EOLIS elevation data generated using swath processing of CryoSat data [(Gourmelen, N., Escorihuela, M., Shepherd, A., Foresta, L., Muir, A., Garcia-Mondejar, A., Roca, M., Baker, S., & Drinkwater, M. R. (2018))](https://doi.org/10.1016/j.asr.2017.11.014) and provided by the [ESA CryoTEMPO project](https://cryotempo-eolis.org/)

- data downloaded from [cs2eo](https://cs2eo.org/) using [this search query](https://cs2eo.org/search?searchMode=single-polygon&productA=TEMPO_SWATH_GRID&polygon=[[-50.35,64.23],[-49.1,64.25],[-49.03,63.71],[-50.26,63.67],[-50.35,64.23]]&startDate=2010-01-01&startTime=00:00&endDate=2023-01-01&endTime=00:00&trackSpacing=100&batchRequest=false)
the `.csv` file generated from this is saved in [here](/data/sec/cryosat/TEMPO_SWATH_GRID_56b0c8ea-d54e-11ed-86cd-7b7bd7ce6023.csv). This contains links to individual `.nc` files which are not included in this repo. Code required to download is included in within [`plot_figures.ipynb`](/code/plot_figures.ipynb/)

#### ICESat2 ATL15
[ATLAS/ICESat-2 L3B Gridded Antarctic and Arctic Land Ice Height Change, Version 2 (ATL15)](https://nsidc.org/data/atl15/versions/2#anchor-2) (Smith et al., 2021) is a gridded elevation change data set derived from ICESat-2. Provides height-change estimates at 3-month intervals from October 2018-April 2022. 
- Data downloaded from using the following `wget` command.
- Requires Earth Data credentials.
                       
```
wget --http-user=<USERNAME> --http-password=<PASSWORD> --load-cookies mycookies.txt --save-cookies mycookies.txt --keep-session-cookies --no-check-certificate --auth-no-challenge -r --reject "index.html*" -np -e robots=off https://n5eil01u.ecs.nsidc.org/DP7/ATLAS/ATL15.002/2019.03.29/ATL15_GL_0314_01km_002_01.nc
```
#### Arctic DEM
High resolution time dependent DEMs [(Porter et al., 2018)](https://doi.org/10.7910/DVN/OHHUKH). 
- No download required
- [Arctic DEM strips, v3](https://developers.google.com/earth-engine/datasets/catalog/UMN_PGC_ArcticDEM_V3_2m#description) dataset is accessed using Google Earth Engine's python API. Requires an Earth Engine account.
***
### Runoff
Greenland liquid water discharge [(Mankoff et al., 2020)](https://doi.org/10.5194/essd-12-2811-2020). Derived from two climate models (MAR and RACMO)
- downloaded from [here](https://doi.org/10.22008/FK2/XKQVL7), or use the following `wget` command:
```
wget -r -e robots=off -nH --cut-dirs=3 --content-disposition "https://dataverse.geus.dk/api/datasets/:persistentId/dirindex?persistentId=doi:10.22008/FK2/XKQVL7"
```
